@@ -43,9 +43,7 @@ class Resources(horizon.PanelGroup):
     panels = (
         'resources.overview',
         'resources.resource',
-        'resources.management',
-        'resources.unallocated',
-        'resources.archived',
+        'resources.free',
     )
 
 
